ClientWrapper

Struct ClientWrapper 

pub struct ClientWrapper<RB, T>(/* private fields */)
where
    T: GenericClient<RB>;
Wrapper type for generic HTTP clients.

This wrapper provides a unified interface for creating HTTP requests across different backend implementations. It provides convenience methods for common HTTP methods like GET, POST, PUT, etc.

Most users should use the type aliases exported by this crate (ReqwestClient, SimulatorClient, etc.) rather than using this wrapper directly.

Implementations

Source

impl ClientWrapper<RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>, Client>

pub fn new() -> ClientWrapper<RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>, Client>

Create a new HTTP client with default configuration.

Panics
  • If the empty ClientBuilder somehow fails to build
pub const fn builder() -> ClientBuilderWrapper<RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>, ClientWrapper<RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>, Client>, ClientBuilder>

Create a new client builder for configuring the HTTP client.

pub fn get( &self, url: &str, ) -> RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>

Create a GET request builder for the specified URL.

pub fn post( &self, url: &str, ) -> RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>

Create a POST request builder for the specified URL.

pub fn put( &self, url: &str, ) -> RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>

Create a PUT request builder for the specified URL.

pub fn patch( &self, url: &str, ) -> RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>

Create a PATCH request builder for the specified URL.

pub fn delete( &self, url: &str, ) -> RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>

Create a DELETE request builder for the specified URL.

pub fn head( &self, url: &str, ) -> RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>

Create a HEAD request builder for the specified URL.

pub fn options( &self, url: &str, ) -> RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>

Create an OPTIONS request builder for the specified URL.

pub fn request( &self, method: Method, url: &str, ) -> RequestBuilderWrapper<ResponseWrapper<Response>, RequestBuilder>

Create a request builder with the specified HTTP method and URL.