Module barrier

Module barrier 

Barrier synchronization primitive for simulator runtime.

This provides a barrier that allows multiple tasks to synchronize at the same point. The implementation uses oneshot channels to coordinate between waiting tasks.

Structs

Barrier
A barrier enables multiple tasks to synchronize the beginning of some computation.
BarrierWaitResult
A result returned from Barrier::wait when all tasks in the barrier have rendezvoused.