pub enum TrySendError<T> {
Full(T),
Disconnected(T),
}Expand description
An error that may be emitted when attempting to send a value into a channel on a sender when the channel is full or all receivers are dropped.
Variants
Full(T)
The channel the message is sent on has a finite capacity and was full when the send was attempted.
Disconnected(T)
All channel receivers were dropped and so the message has nobody to receive it.
Implementations
Sourceimpl<T> TrySendError<T>
impl<T> TrySendError<T>
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume the error, yielding the message that failed to send.