pub enum Error {
Http {
status_code: StatusCode,
source: Box<dyn Error + Send + Sync>,
},
}Expand description
Web server error types.
This enum represents errors that can occur during HTTP request processing. All variants include a status code and source error for detailed error reporting.
Variants
Http- HTTP error with associated status code and source error
Variants
Http
HTTP error with associated status code and source error
Implementations
Sourceimpl Error
impl Error
Sourcepub const fn status_code(&self) -> StatusCode
pub const fn status_code(&self) -> StatusCode
Returns the HTTP status code associated with this error.
Sourcepub fn from_http_status_code(
status_code: StatusCode,
source: impl Error + Send + Sync + 'static,
) -> Error
pub fn from_http_status_code( status_code: StatusCode, source: impl Error + Send + Sync + 'static, ) -> Error
Creates an HTTP error with the specified status code and source error.
Sourcepub fn from_http_status_code_u16(
status_code: u16,
source: impl Error + Send + Sync + 'static,
) -> Error
pub fn from_http_status_code_u16( status_code: u16, source: impl Error + Send + Sync + 'static, ) -> Error
Creates an HTTP error with the specified status code (as u16) and source error.
Sourcepub fn bad_request(error: impl Into<Box<dyn Error + Send + Sync>>) -> Error
pub fn bad_request(error: impl Into<Box<dyn Error + Send + Sync>>) -> Error
Creates a 400 Bad Request error.
Creates a 401 Unauthorized error.