pub struct UpsertStatement<'a> {
pub table_name: &'a str,
pub values: Vec<(&'a str, Box<dyn Expression>)>,
pub filters: Option<Vec<Box<dyn BooleanExpression>>>,
pub unique: Option<&'a [&'a str]>,
pub limit: Option<usize>,
}Expand description
UPSERT statement for inserting or updating a row on conflict
Fields
table_name: &'a strTable to upsert into
values: Vec<(&'a str, Box<dyn Expression>)>Column-value pairs to insert/update
filters: Option<Vec<Box<dyn BooleanExpression>>>WHERE clause filters for conditional upsert
unique: Option<&'a [&'a str]>Columns that form the unique constraint to detect conflicts
limit: Option<usize>Maximum number of rows to upsert
Implementations
Sourceimpl<'a> UpsertStatement<'a>
impl<'a> UpsertStatement<'a>
Sourcepub fn values<T>(self, values: Vec<(&'a str, T)>) -> UpsertStatement<'a>
pub fn values<T>(self, values: Vec<(&'a str, T)>) -> UpsertStatement<'a>
Sets multiple column-value pairs to upsert
Sourcepub fn value<T>(self, name: &'a str, value: T) -> UpsertStatement<'a>
pub fn value<T>(self, name: &'a str, value: T) -> UpsertStatement<'a>
Sets a single column-value pair to upsert
Sourcepub fn value_opt<T>(
self,
name: &'a str,
value: Option<T>,
) -> UpsertStatement<'a>
pub fn value_opt<T>( self, name: &'a str, value: Option<T>, ) -> UpsertStatement<'a>
Sets a column-value pair only if the value is Some
This is useful for conditional updates where a value should only be set if present.
Sourcepub const fn unique(self, unique: &'a [&'a str]) -> UpsertStatement<'a>
pub const fn unique(self, unique: &'a [&'a str]) -> UpsertStatement<'a>
Specifies unique columns that identify conflicts
These columns determine when to update instead of insert.
Sourcepub const fn limit(self, limit: usize) -> UpsertStatement<'a>
pub const fn limit(self, limit: usize) -> UpsertStatement<'a>
Limits the number of rows affected by the upsert
Sourcepub async fn execute(self, db: &dyn Database) -> Result<Vec<Row>, DatabaseError>
pub async fn execute(self, db: &dyn Database) -> Result<Vec<Row>, DatabaseError>
Errors
Will return Err if the upsert execution failed.
Sourcepub async fn execute_first(
self,
db: &dyn Database,
) -> Result<Row, DatabaseError>
pub async fn execute_first( self, db: &dyn Database, ) -> Result<Row, DatabaseError>
Errors
Will return Err if the upsert execution failed.