pub fn epoch_offset() -> u64Expand description
Returns the current epoch offset in milliseconds.
The epoch offset is the base Unix timestamp used for time simulation. If not previously set, generates and caches a new random value.
Panics
- If the
EPOCH_OFFSETRwLockfails to read from or write to - If
SIMULATOR_EPOCH_OFFSETis set but cannot be parsed as au64 - If
SIMULATOR_EPOCH_MINandSIMULATOR_EPOCH_MAXare not both set when either is provided - If
SIMULATOR_EPOCH_MINorSIMULATOR_EPOCH_MAXcannot be parsed asu64 - If
SIMULATOR_EPOCH_MINis greater thanSIMULATOR_EPOCH_MAX - If
SIMULATOR_EPOCH_RANGE_PROFILEis set to an unsupported value