pub struct TryReadyChunksError<T, E>(pub Vec<T>, pub E);Expand description
Error indicating, that while chunk was collected inner stream produced an error.
Contains all items that were collected before an error occurred, and the stream error itself.
Tuple Fields
0: Vec<T>1: ETrait Implementations
Sourceimpl<T, E> Debug for TryReadyChunksError<T, E>where
E: Debug,
impl<T, E> Debug for TryReadyChunksError<T, E>where
E: Debug,
Sourceimpl<T, E> Display for TryReadyChunksError<T, E>where
E: Display,
impl<T, E> Display for TryReadyChunksError<T, E>where
E: Display,
impl<T, E> Eq for TryReadyChunksError<T, E>
Sourceimpl<T, E> Error for TryReadyChunksError<T, E>
Available on crate feature std only.
impl<T, E> Error for TryReadyChunksError<T, E>
Available on crate feature
std only.1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl<T, E> PartialEq for TryReadyChunksError<T, E>
impl<T, E> PartialEq for TryReadyChunksError<T, E>
Sourcefn eq(&self, other: &TryReadyChunksError<T, E>) -> bool
fn eq(&self, other: &TryReadyChunksError<T, E>) -> bool
Tests for
self and other values to be equal, and is used by ==.impl<T, E> StructuralPartialEq for TryReadyChunksError<T, E>