Barrier synchronization primitive for simulator runtime.
This provides a barrier that allows multiple tasks to synchronize at the same point. The implementation uses oneshot channels to coordinate between waiting tasks.
Structs
- Barrier
- A barrier enables multiple tasks to synchronize the beginning of some computation.
- Barrier
Wait Result - A result returned from
Barrier::waitwhen all tasks in the barrier have rendezvoused.